@@ -800,13 +800,14 @@ but before other extensions. Gets cleared just like C<@TERM_INIT>.
 
 =item urxvt::fatal $errormessage
 
-Fatally aborts execution with the given error message. Avoid at all
-costs! The only time this is acceptable is when the terminal process
-starts up.
+Fatally aborts execution with the given error message (which should
+include a trailing newline). Avoid at all costs! The only time this
+is acceptable (and useful) is in the init hook, where it prevents the
+terminal from starting up.
 
 =item urxvt::warn $string
 
-Calls C<rxvt_warn> with the given string which should not include a
+Calls C<rxvt_warn> with the given string which should include a trailing
 newline. The module also overwrites the C<warn> builtin with a function
 that calls this function.
 
@@ -873,7 +874,8 @@ being reset. Useful as a base to start when creating renditions.
 
 Return the rendition mask used for overlays by default.
 
-=item $rendbit = urxvt::RS_Bold, RS_Italic, RS_Blink, RS_RVid, RS_Uline
+=item $rendbit = urxvt::RS_Bold, urxvt::RS_Italic, urxvt::RS_Blink,
+urxvt::RS_RVid, urxvt::RS_Uline
 
 Return the bit that enabled bold, italic, blink, reverse-video and
 underline, respectively. To enable such a style, just logically OR it into
@@ -2251,7 +2253,7 @@ numbers indicate more verbose output.
 
 =head1 AUTHOR
 
- Marc Lehmann <pcg@goof.com>
+ Marc Lehmann <schmorp@schmorp.de>
  http://software.schmorp.de/pkg/rxvt-unicode
 
 =cut
